#!/usr/local/bin/python

# Front-end for archie written in Python
# Uses the expect module
#
# Author  : Farzad FARID <faridf6@cti.ecp.fr>
# Version : 1.0
# Date    : 95/04/07

import sys, os, expect, string, commands

#
# Change the values here to your convenience
#
# Default server
server =  'archie.univ-rennes1.fr'
# Your email address
user = 'faridf6@cti.ecp.fr'
# Default search type
search = 'sub'
# Default terminal type, only used if the TERM env variable is not found
defterm = 'vt100'
# Default screen size
defcols = '80'
defrows = '24' 
# This is the prompt returned by the archie server, if your server
# uses a different prompt you must change this string, otherwise
# the program will not know when archie is ready
prompt  = 'archie> '
# Timeout for expect, in seconds
timeout = 30


# Set the terminal type and size
def setterm():
    global term, rows, cols
    # Try to guess the terminal type and size
    try:
	term = os.environ['TERM']
    except:
	term = defterm
    try:
	error, size = commands.getstatusoutput('stty size')
	if (not error):
	    [rows, cols] = string.split(size)
	else:
	    rows, cols = defrows, defcols
    except:
	rows, cols = defrows, defcols


# Wait for the prompt and send the string
def promptandsend(line):
    expect.expect([(exp, (expect.exact, prompt, 0))])
    exp.send(line)


## Main routine 
argv0 = sys.argv[0]
expect.setdeftimeout(timeout)
expect.setdefloguser(1)

setterm()

try:
    exp = expect.spawn('telnet', [ 'telnet', server ])
except:
    print "%s: spawn unsuccessfull" % argv0
    print sys.exc_type, ':', sys.exc_value
    sys.exit(1)

print "%s: telnet spawned with pid %d" % (argv0, exp.pid)

# Wait for the login prompt
try:
    expect.expect([(exp, (expect.exact, 'login: ', 0))])
except expect.timeout:
    print "%s : timeout, aborting." % argv0
    sys.exit(1)
except expect.eof:
    print "%s: EOF received, aborting." % argv0
    sys.exit(1)
except:
    print "Unexpected error: ", sys.exc_type, ':', sys.exc_value
    sys.exit(1)

# Now log in
exp.send('archie\n')

try:
    promptandsend('set term %s %s %s\n' % (term, rows, cols))
    promptandsend('set pager\n')
    promptandsend('set mailto %s\n' % user)
    promptandsend('set search %s\n' % search)
    promptandsend('')
except expect.timeout:
    print "%s : timeout, aborting." % argv0
    sys.exit(1)
except expect.eof:
    print "%s: EOF received, aborting." % argv0
    sys.exit(1)
except:
    print "Unexpected error: ", sys.exc_type, ':', sys.exc_value
    sys.exit(1)

# Now let the user interact with the program
try:
    exp.interact('\x4')  # Ctrl-D is the escape character
    exp.send('quit\n')
except expect.eof:
    # We get this one if the user types 'quit' for example
    pass
except:
    # Catch all other errors
    print '%s: caught exception: %s : %s' % (argv0,
					     sys.exc_type, sys.exc_value)


print '%s: end of the program' % argv0
sys.exit(0)
